summaryrefslogtreecommitdiff
path: root/gtk2_ardour/streamview.cc
diff options
context:
space:
mode:
authorNick Mainsbridge <beatroute@iprimus.com.au>2009-12-12 12:33:36 +0000
committerNick Mainsbridge <beatroute@iprimus.com.au>2009-12-12 12:33:36 +0000
commit0c80b01f4724922a95d22fc441d6854da001c442 (patch)
tree54fadcb989f25838590ee90af0ede1d0f3ec0187 /gtk2_ardour/streamview.cc
parent401c7091c805b24b926acb2b393070d3a32628a6 (diff)
Fix canvas region layering in non-Stacked modes. Remove unused and confusing TimeAxisViewItem::selected .
git-svn-id: svn://localhost/ardour2/branches/3.0@6356 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'gtk2_ardour/streamview.cc')
-rw-r--r--gtk2_ardour/streamview.cc9
1 files changed, 6 insertions, 3 deletions
diff --git a/gtk2_ardour/streamview.cc b/gtk2_ardour/streamview.cc
index 1be1f7ede5..dd5da01b0f 100644
--- a/gtk2_ardour/streamview.cc
+++ b/gtk2_ardour/streamview.cc
@@ -290,9 +290,9 @@ StreamView::layer_regions()
i = tmp;
}
// Fix canvas layering by raising each in the sorted list order
for (RegionViewList::iterator i = copy.begin(); i != copy.end(); ++i) {
- region_layered (*i);
+ (*i)->get_canvas_group()->raise_to_top ();
}
}
@@ -320,7 +320,10 @@ StreamView::playlist_modified (boost::shared_ptr<Diskstream> ds)
if (_layer_display == Stacked) {
update_contents_height ();
update_coverage_frames ();
- }
+ } else {
+ /* layering has probably been modified. reflect this in the canvas. */
+ layer_regions();
+ }
}
void
@@ -290,9 +290,9 @@ StreamView::layer_regions()
i = tmp;
}
- // Fix canvas layering by raising each in the sorted list order
+ // Fix canvas layering by raising each to the top in the sorted order.
for (RegionViewList::iterator i = copy.begin(); i != copy.end(); ++i) {